intelmq.bots.collectors.amqp package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.collectors.amqp package

## Submodules

## intelmq.bots.collectors.amqp.collector_amqp module

Collecting from a (remote) AMQP Server and fetching either intelmq or any other messages.

class intelmq.bots.collectors.amqp.collector_amqp.AMQPCollectorBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.bots.outputs.amqptopic.output.AMQPTopicOutputBot`, `intelmq.lib.bot.CollectorBot`

  Collect data from an AMQP Server and fetch either intelmq or any other messages. Requires the pika python library. Inheriting from AMQPTopicOutputBot for connect_server method

  connection_attempts: int = 3
  connection_heartbeat: int = 3600
  connection_host: str = '127.0.0.1'
  connection_port: int = 5672
  connection_vhost: str = None
  expect_intelmq_message: bool = False
  init()
  password: str = None
  process()

    Stop the Bot if cannot connect to AMQP Server after the defined connection attempts

  queue_name: str = None
  use_ssl: bool = False
  username: str = None

intelmq.bots.collectors.amqp.collector_amqp.BOT

  alias of `intelmq.bots.collectors.amqp.collector_amqp.AMQPCollectorBot`

## Module contents